#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  local IMAGE_NAME=`uci get searxng.@searxng[0].image_name 2>/dev/null`
}

do_install_detail() {
  local config=`uci get searxng.@searxng[0].config_path 2>/dev/null`
  local port=`uci get searxng.@searxng[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get searxng.@searxng[0].image_name 2>/dev/null`
  local username=`uci get searxng.@searxng[0].username 2>/dev/null`
  local password=`uci get searxng.@searxng[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8123
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=paulgoio/searxng:production

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch /root/docker-compose/searxng-app/docker-compose.yml
cat > /root/docker-compose/searxng-app/docker-compose.yml <<EOF
version: '3.7'

services:
  searxng:
    image: $IMAGE_NAME
    restart: always
    ports:
      - ${LAN_IP}:$port:8080
    cap_drop:
      - ALL
    cap_add:
      - SETGID
      - SETUID
      - DAC_OVERRIDE
    environment:
      - IMAGE_PROXY=true
      - BASE_URL=http://${LAN_IP}
      - NAME=searx
      - CONTACT=contact@searxng.org
      - ISSUE_URL=https://github.com/paulgoio/searxng/issues
      - GIT_URL=https://github.com/paulgoio/searxng
      - GIT_BRANCH=main
    labels:
      plugsy.name: "SearXng"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/boxicons-regular/Search"
      plugsy.link: "http://${LAN_IP}:$port"
EOF
  
  dockerdeploy searxng-app
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install searxng"
  echo "      upgrade                Upgrade searxng"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart searxng"
  echo "      status                 searxng status"
  echo "      port                   searxng port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker ps -a --filter "$IMAGE_NAME" --format '{{.ID}}' | xargs -r docker stop && docker ps -a --filter "$IMAGE_NAME" --format '{{.ID}}' | xargs -r docker rm && docker rmi $IMAGE_NAME

    docker rm -f searxng
  ;;
  "start" | "stop" | "restart")
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    docker ${ACTION} ${ID}
  ;;
  "status")
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${NAME}" --format '{{.Status}}'
  ;;
  "port")
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${NAME}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
